Module parser

Module parser 

Structs

Indent
Indentation specification for wrapped/continuation lines.

Enums

IndentChar
The type of indent character used for wrapped/continuation lines.
Token
A parsed template element — either literal text, a color token, or a placeholder token.
TokenKind
The type of placeholder token in a template string.

Functions

parse
Parse a template string into a sequence of tokens.