pub fn render(entry: &Entry, options: &RenderOptions, config: &Config) -> StringExpand description
Render a single entry against a template string, returning the formatted output.
pub fn render(entry: &Entry, options: &RenderOptions, config: &Config) -> StringRender a single entry against a template string, returning the formatted output.