Enums
- Color
- A named ANSI color or modifier that can appear as a
%colortoken in templates. - Named
Color - A named ANSI color attribute.
Statics
Functions
- init
- Initialize color output with terminal detection.
- strip_
ansi - Strip all ANSI escape sequences from a string.
- validate_
color - Validate a color name string, returning the longest valid prefix and its original length.
- visible_
len - Return the visible (non-ANSI) display width of a string.