Structs
- Indent
- Indentation specification for wrapped/continuation lines.
Enums
- Indent
Char - The type of indent character used for wrapped/continuation lines.
- Token
- A parsed template element — either literal text, a color token, or a placeholder token.
- Token
Kind - The type of placeholder token in a template string.
Functions
- parse
- Parse a template string into a sequence of tokens.